Learn R Programming

disaggR (version 1.0.5.4)

bflSmooth_matrices_factory: Generating a clone for bflSmooth_matrices_impl

Description

This function factory returns a clone of bflSmooth_matrices_impl that gives the same results than the original function but uses cache to store computed matrices, which is useful when making a large number of similar calls, like calls to threeRuleSmooth() with the same hfserie but different lfserie, or to twoStepsBenchmark() with different lfserie of the same length.

Usage

bflSmooth_matrices_factory(cache_size = 100L)

Arguments

Details

bflSmooth_matrices_factory is only run at build time.