Learn R Programming

disaggR (version 1.0.5.4)

extend_tsp: Extend tsp with lf

Description

This window is the smallest that is all around tsphf that is compatible with the low frequency.

Usage

extend_tsp(tsphf, lffreq)

Value

a numeric of length 3, a tsp of high-frequency.

Arguments

tsphf

a numeric of length 3, a tsp of high-frequency

lffreq

a numeric of length 1, the low frequency