in_disaggr: Comparing a disaggregation with the high-frequency input
Description
The function in_disaggr takes a twoStepsBenchmark or a
threeRuleSmooth object as an input. It produces a comparison between
the benchmarked time series and the high-frequency input.
Usage
in_disaggr(object, type = "changes")
Value
a named matrix time series of two columns, one for the response and the other
for the input.
A tscomparison class is added to the object.
Arguments
object
an object of class "twoStepsBenchmark" or "threeRuleSmooth".
type
"levels","levels-rebased", "changes" or "contributions".
This defines the type of output.
Details
The functions plot and autoplot can be used on this object to produce
graphics.