powered by
The function in_revisionstakes two inputs, twoStepsBenchmark or a threeRuleSmooth, and produces a comparison between those.
in_revisions
in_revisions(object, object_old, type = "changes")
a named matrix time series of two columns, one for the response and the other for the predicted value. A tscomparison class is added to the object.
tscomparison
an object of class "twoStepsBenchmark" or "threeRuleSmooth".
"twoStepsBenchmark"
"threeRuleSmooth"
"levels","levels-rebased", "changes" or "contributions". This defines the type of output.
"levels"
"levels-rebased"
"changes"
"contributions"
The functions plot and autoplot can be used on this object to produce graphics.
plot
autoplot
in_sample in_disaggr in_scatter plot.tscomparison
benchmark <- twoStepsBenchmark(turnover,construction,include.rho = TRUE) benchmark2 <- twoStepsBenchmark(turnover,construction,include.differenciation = TRUE) plot(in_revisions(benchmark,benchmark2))
Run the code above in your browser using DataLab