a named matrix time series of two or three columns, one for the low-frequency serie
and the others for the high-frequency series (eventually differentiated if
include.differenciation is TRUE).
A tscomparison class is added to the object.
For a twoStepsBenchmark object, this matrix has three columns,
for the low-frequency series, the high-frequency on the regression span and
the high-frequency series on the benchmark span.
If outlier effects are estimated, the contributions of the outliers are
substracted from the low-frequency series.