The function outliers returns the outliers
from either a praislm or a twoStepsBenchmark object.
outliers(object, as.ts = FALSE)a named list or a time series, depending of the
argument "as.ts".
a praislm or twoStepsBenchmark object.
a boolean of length 1. If TRUE, the returned
outliers are returned as a time series with (dim and colnames).
If FALSE, the returned outliers is the named list that was
submitted as a function argument.