prais extracts the regression, which is an object of class "praislm", of a
twoStepsBenchmark object.
prais(x)praislm(X, y, include.rho, include.differenciation, set_coefficients, cl)
prais returns an object of class "praislm".
The functions that can be used on that class are almost the same than
for the class twoStepsBenchmark.
summary, coefficients, residuals will return the same values.
However, as for fitted.values, the accessor returns the fitted values
of the regression, not the high-frequency, eventually integrated, time series
contained in a twoStepsBenchmark.
An object of class "praislm" is a list containing the following components :
a named vector of coefficients.
the residuals, that is response minus fitted values.
a time series, the fitted mean values
a named vector of standard errors.
the residual degrees of freedom.
the autocorrelation coefficients of the residuals. It
is equal to zero if twoStepsBenchmark was called with include.rho=FALSE
the residuals of the model after having been transformed by rho in a least square model.
the fitted values of the model after having been transformed by rho in a least square model.
a twoStepsBenchmark
benchmark <- twoStepsBenchmark(turnover,construction); prais(benchmark)
Run the code above in your browser using DataLab