This function is the rule to extrapolate the low-frequency residuals.
If include.differenciation is TRUE, u(n+1)-u(n) = rho*(u(n)-u(n-1))
Else u(n+1) = rho * u(n)
residuals_extrap(lfresiduals, rho, include.differenciation)a numeric, the extrapolated sequence of residuals, to replace the NA of the residuals
the residuals to extrapolate
the autocorrelation parameter of the regression
a boolean, the same as submitted to twoStepsBenchmark